@@ -71,7 +71,6 @@ PROTO_FILES = [
     TSCHArchives_Common,
 ]
 
-
 TSPRegistryMapping = {
     "1": "TN.DocumentArchive",
     "2": "TN.SheetArchive",
@@ -217,7 +216,6 @@ TSPRegistryMapping = {
     "2119": "TSWP.UpdateDateTimeFieldCommandArchive",
     "2120": "TSWP.ModifyTOCSettingsBaseCommandArchive",
     "2121": "TSWP.ModifyTOCSettingsForTOCInfoCommandArchive",
-    "2122": "TSWP.ModifyTOCSettingsPresetForThemeCommandArchive",
     "2123": "TSWP.SetObjectPropertiesCommandArchive",
     "2124": "TSWP.UpdateFlowInfoCommandArchive",
     "2125": "TSWP.AddFlowInfoCommandArchive",
@@ -653,11 +651,13 @@ def compute_maps():
             add_nested_types(message_type)
 
     id_name_map = {}
+    name_id_map = {}
     for k, v in list(TSPRegistryMapping.items()):
         if v in name_class_map:
             id_name_map[int(k)] = name_class_map[v]
+            name_id_map[v] = int(k)
 
-    return name_class_map, id_name_map
+    return name_class_map, id_name_map, name_id_map
 
 
-NAME_CLASS_MAP, ID_NAME_MAP = compute_maps()
+NAME_CLASS_MAP, ID_NAME_MAP, NAME_ID_MAP = compute_maps()
